@@ -1009,7 +1009,7 @@ class BaseWidgetContainer
 		
 		if (!empty($act)) return $configId;		// 初期呼び出し時以外は終了
 		
-		$value = $request->trimValueOf('_defconfig');
+		$value = $request->trimValueOf(M3_REQUEST_PARAM_PAGE_DEF_CONFIG_ID);
 		if ($value != '') $configId = intval($value);
 		if ($configId < 0) $configId = 0;		// エラー値を修正
 		return $configId;
@@ -1026,7 +1026,7 @@ class BaseWidgetContainer
 		
 		if (!empty($act)) return $serial;		// 初期呼び出し時以外は終了
 		
-		$value = $request->trimValueOf('_defserial');
+		$value = $request->trimValueOf(M3_REQUEST_PARAM_PAGE_DEF_SERIAL);
 		if ($value != '') $serial = intval($value);
 		if ($serial < 0) $serial = 0;		// エラー値を修正
 		return $serial;
