@@ -838,6 +838,7 @@ class SystemDb extends BaseDb
 			$queryStr .=   'pd_index, ';
 			$queryStr .=   'pd_widget_id, ';
 			$queryStr .=   'pd_config_id, ';
+			$queryStr .=   'pd_config_name, ';
 			$queryStr .=   'pd_suffix, ';
 			$queryStr .=   'pd_style, ';
 			$queryStr .=   'pd_visible, ';
@@ -857,9 +858,10 @@ class SystemDb extends BaseDb
 			$queryStr .=   '?, ';
 			$queryStr .=   '?, ';
 			$queryStr .=   '?, ';
+			$queryStr .=   '?, ';
 			$queryStr .=   '?)';
 			$this->execStatement($queryStr, array($pageId, $newPageSubId, $row['pd_set_id'], $row['pd_position_id'], $row['pd_index'], 
-								$row['pd_widget_id'], $row['pd_config_id'], $row['pd_suffix'], $row['pd_style'], $row['pd_visible'], $row['pd_editable'], $userId, $now));
+								$row['pd_widget_id'], $row['pd_config_id'], $row['pd_config_name'], $row['pd_suffix'], $row['pd_style'], $row['pd_visible'], $row['pd_editable'], $userId, $now));
 								
 			// 旧データ削除
 			$queryStr  = 'DELETE FROM _page_def WHERE pd_serial = ?';
@@ -1070,6 +1072,91 @@ class SystemDb extends BaseDb
 		$ret = $this->endTransaction();
 		return $ret;
 	}
+	/**
+	 * ログインユーザのアクセス可能機能を削除
+	 *
+	 * @param int	$id						ユーザID
+	 * @param string	$accessType			削除する機能
+	 * @param bool		$deleteUser			アクセス可能機能がすべて削除になったとき、ユーザを削除するかどうか
+	 * @return bool							取得 = true, 取得なし= false
+	 */
+	function releaseLoginUser($id, $accessType, $deleteUser = false)
+	{
+		global $gEnvManager;
+		
+		$startTran = false;			// この関数でトランザクションを開始したかどうか
+		$now = date("Y/m/d H:i:s");	// 現在日時
+		$userId = $gEnvManager->getCurrentUserId();	// 現在のユーザ
+		
+		// トランザクション開始
+		if (!$this->isInTransaction()){
+			$this->startTransaction();
+			$startTran = true;
+		}
+		
+		// 指定のIDのレコードが削除状態でないかチェック
+		$queryStr  = 'select * from _login_user ';
+		$queryStr .=   'WHERE lu_id = ? ';
+		$queryStr .=    'and lu_deleted = false';
+		$ret = $this->selectRecord($queryStr, array($id), $row);
+		if (!$ret){		// 登録レコードがないとき
+			if ($startTran) $this->endTransaction();
+			return false;
+		}
+		
+		// 機能のアサイン状況を取得
+		$replaceStr = $accessType . ',';
+		$assign = $row['lu_assign'];
+		$pos = strpos($assign, $replaceStr);
+		if ($pos === false){// 見つからないとき
+			if ($startTran) $this->endTransaction();
+			return false;
+		} else {
+			$assign = str_replace($replaceStr, '', $assign);
+		}
+
+		// 古いレコードを削除
+		$queryStr  = 'UPDATE _login_user ';
+		$queryStr .=   'SET lu_deleted = true, ';	// 削除
+		$queryStr .=     'lu_update_user_id = ?, ';
+		$queryStr .=     'lu_update_dt = ? ';
+		$queryStr .=   'WHERE lu_serial = ?';
+		$ret = $this->execStatement($queryStr, array($userId, $now, $row['lu_serial']));
+		
+		if (!$deleteUser || !empty($assign)){		// ユーザ削除しないとき
+			// 新規レコード追加
+			$queryStr  = 'INSERT INTO _login_user (';
+			$queryStr .=   'lu_id, ';
+			$queryStr .=   'lu_history_index, ';
+			$queryStr .=   'lu_name, ';
+			$queryStr .=   'lu_account, ';
+			$queryStr .=   'lu_password, ';
+			$queryStr .=   'lu_user_type, ';
+			$queryStr .=   'lu_assign, ';
+			$queryStr .=   'lu_widget_id, ';
+			$queryStr .=   'lu_enable_login, ';
+			$queryStr .=   'lu_create_user_id, ';
+			$queryStr .=   'lu_create_dt ';
+			$queryStr .= ') VALUES (';
+			$queryStr .=   '?, ';
+			$queryStr .=   '?, ';
+			$queryStr .=   '?, ';
+			$queryStr .=   '?, ';
+			$queryStr .=   '?, ';
+			$queryStr .=   '?, ';
+			$queryStr .=   '?, ';
+			$queryStr .=   '?, ';
+			$queryStr .=   '?, ';
+			$queryStr .=   '?, ';
+			$queryStr .=   '?) ';
+			$ret = $this->execStatement($queryStr, array($row['lu_id'], $row['lu_history_index'] + 1, $row['lu_name'], $row['lu_account'], $row['lu_password'], 
+														$row['lu_user_type'], $assign, $row['lu_widget_id'], $row['lu_enable_login'], $userId, $now));
+		}
+		
+		// トランザクション確定
+		if ($startTran) $ret = $this->endTransaction();
+		return $ret;
+	}
 	/**
 	 * 管理者権限があるかどうかをIDで取得
 	 *
@@ -1134,7 +1221,7 @@ class SystemDb extends BaseDb
 		$queryStr .=   'lu_account, ';
 		$queryStr .=   'lu_password, ';
 		$queryStr .=   'lu_user_type, ';
-		$queryStr .=   'lu_subject, ';
+		$queryStr .=   'lu_assign, ';
 		$queryStr .=   'lu_widget_id, ';
 		$queryStr .=   'lu_enable_login, ';
 		$queryStr .=   'lu_create_user_id, ';
@@ -1155,7 +1242,7 @@ class SystemDb extends BaseDb
 		$queryStr .=   '?, ';
 		$queryStr .=   '?, ';
 		$queryStr .=   '?) ';
-		$this->execStatement($queryStr, array($row['lu_id'], $row['lu_history_index'] + 1, $row['lu_name'], $row['lu_account'], $password, $row['lu_user_type'], $row['lu_subject'], $row['lu_widget_id'], $row['lu_enable_login'], $userId, $now));
+		$this->execStatement($queryStr, array($row['lu_id'], $row['lu_history_index'] + 1, $row['lu_name'], $row['lu_account'], $password, $row['lu_user_type'], $row['lu_assign'], $row['lu_widget_id'], $row['lu_enable_login'], $userId, $now));
 		
 		// トランザクション確定
 		if ($startTran) $ret = $this->endTransaction();
@@ -1208,7 +1295,7 @@ class SystemDb extends BaseDb
 		$queryStr .=   'lu_account, ';
 		$queryStr .=   'lu_password, ';
 		$queryStr .=   'lu_user_type, ';
-		$queryStr .=   'lu_subject, ';
+		$queryStr .=   'lu_assign, ';
 		$queryStr .=   'lu_widget_id, ';
 		$queryStr .=   'lu_enable_login, ';
 		$queryStr .=   'lu_create_user_id, ';
@@ -1225,7 +1312,7 @@ class SystemDb extends BaseDb
 		$queryStr .=   '?, ';
 		$queryStr .=   '?, ';
 		$queryStr .=   '?) ';
-		$ret = $this->execStatement($queryStr, array($row['lu_id'], $row['lu_history_index'] + 1, $row['lu_name'], $account, $row['lu_password'], $row['lu_user_type'], $row['lu_subject'], $row['lu_widget_id'], $row['lu_enable_login'], $userId, $now));
+		$ret = $this->execStatement($queryStr, array($row['lu_id'], $row['lu_history_index'] + 1, $row['lu_name'], $account, $row['lu_password'], $row['lu_user_type'], $row['lu_assign'], $row['lu_widget_id'], $row['lu_enable_login'], $userId, $now));
 		
 		// トランザクション確定
 		if ($startTran) $ret = $this->endTransaction();
@@ -1280,7 +1367,7 @@ class SystemDb extends BaseDb
 		$queryStr .=   'lu_account, ';
 		$queryStr .=   'lu_password, ';
 		$queryStr .=   'lu_user_type, ';
-		$queryStr .=   'lu_subject, ';
+		$queryStr .=   'lu_assign, ';
 		$queryStr .=   'lu_enable_login, ';
 		$queryStr .=   'lu_widget_id, ';
 		$queryStr .=   'lu_create_user_id, ';
@@ -1298,7 +1385,7 @@ class SystemDb extends BaseDb
 		$queryStr .=   '?, ';
 		$queryStr .=   '?) ';
 		$ret = $this->execStatement($queryStr, array($userId, $historyIndex, $row['lu_name'], $row['lu_account'], $row['lu_password'],
-								$userType, $row['lu_subject'], $row['lu_enable_login'], $row['lu_widget_id'], $updateUserId, $now));
+								$userType, $row['lu_assign'], $row['lu_enable_login'], $row['lu_widget_id'], $updateUserId, $now));
 								
 		// トランザクション確定
 		$ret = $this->endTransaction();
@@ -1759,5 +1846,161 @@ class SystemDb extends BaseDb
 		$ret = $this->endTransaction();
 		return $ret;
 	}
+	
+	/**
+	 * ログインユーザ情報を更新
+	 *
+	 * @param int     $id			ログインユーザID
+	 * @param string  $no			ユーザNo(任意使用)
+	 * @param string  $familyName	名前(姓)
+	 * @param string  $firstName	名前(名)
+	 * @param string  $familyNameKana	名前カナ(姓)
+	 * @param string  $firstNameKana	名前カナ(名)
+	 * @param int     $gender		性別(0=男、1=女)
+	 * @param date    $birthday		生年月日
+	 * @param string  $email		Eメール
+	 * @param string  $mobile		携帯電話
+	 * @param string  $zipcode		郵便番号
+	 * @param int     $stateId		都道府県
+	 * @param string  $address1		市区町村
+	 * @param string  $address2		ビル・マンション名等
+	 * @param string  $phone		電話番号
+	 * @param string  $fax			FAX
+	 * @param string  $countryId	国ID
+	 * @param int     $newSerial	新規レコードのシリアル番号
+	 * @return						true=成功、false=失敗
+	 */
+	function updateLoginUserInfo($id, $no, $familyName, $firstName, $familyNameKana, $firstNameKana, $gender, $birthday, $email, $mobile,
+													$zipcode, $stateId, $address1, $address2, $phone, $fax, $countryId, &$newSerial)
+	{
+		global $gEnvManager;
+			
+		$startTran = false;			// この関数でトランザクションを開始したかどうか
+		$now = date("Y/m/d H:i:s");	// 現在日時
+		$userId = $gEnvManager->getCurrentUserId();	// 現在のユーザ
+				
+		// トランザクション開始
+		if (!$this->isInTransaction()){
+			$this->startTransaction();
+			$startTran = true;
+		}
+		
+		// 指定のレコードの履歴インデックス取得
+		$queryStr  = 'SELECT * FROM _login_user_info ';
+		$queryStr .=   'WHERE li_id = ? ';
+		$queryStr .=  'ORDER BY li_history_index desc ';
+		$ret = $this->selectRecord($queryStr, array($id), $row);
+		if ($ret){
+			if (!$row['li_deleted']){		// 削除されていなければ削除
+				// レコードを削除
+				$queryStr  = 'UPDATE _login_user_info ';
+				$queryStr .=   'SET li_deleted = true, ';
+				$queryStr .=   'li_update_user_id = ?, ';
+				$queryStr .=   'li_update_dt = ? ';			
+				$queryStr .=   'WHERE li_serial = ? ';
+				$this->execStatement($queryStr, array($userId, $now, $row['li_serial']));
+			}
+			$historyIndex = $row['li_history_index'] + 1;
+		} else {
+			$historyIndex = 0;
+		}
+	
+		// 新規レコードを追加
+		$queryStr  = 'INSERT INTO _login_user_info (';
+		$queryStr .=   'li_id, ';
+		$queryStr .=   'li_history_index, ';
+		$queryStr .=   'li_no, ';
+		$queryStr .=   'li_family_name, ';
+		$queryStr .=   'li_first_name, ';
+		$queryStr .=   'li_family_name_kana, ';
+		$queryStr .=   'li_first_name_kana, ';
+		$queryStr .=   'li_gender, ';
+		$queryStr .=   'li_birthday, ';
+		$queryStr .=   'li_email, ';
+		$queryStr .=   'li_mobile, ';
+		$queryStr .=   'li_zipcode, ';
+		$queryStr .=   'li_state_id, ';
+		$queryStr .=   'li_address1, ';
+		$queryStr .=   'li_address2, ';
+		$queryStr .=   'li_phone, ';
+		$queryStr .=   'li_fax, ';
+		$queryStr .=   'li_country_id, ';
+		$queryStr .=   'li_create_user_id, ';
+		$queryStr .=   'li_create_dt ';
+		$queryStr .= ') VALUES (';
+		$queryStr .=   '?, ';
+		$queryStr .=   '?, ';
+		$queryStr .=   '?, ';
+		$queryStr .=   '?, ';
+		$queryStr .=   '?, ';
+		$queryStr .=   '?, ';
+		$queryStr .=   '?, ';
+		$queryStr .=   '?, ';
+		$queryStr .=   '?, ';
+		$queryStr .=   '?, ';
+		$queryStr .=   '?, ';
+		$queryStr .=   '?, ';
+		$queryStr .=   '?, ';
+		$queryStr .=   '?, ';
+		$queryStr .=   '?, ';
+		$queryStr .=   '?, ';
+		$queryStr .=   '?, ';
+		$queryStr .=   '?, ';
+		$queryStr .=   '?, ';
+		$queryStr .=   '?) ';
+		$ret = $this->execStatement($queryStr, array($id, $historyIndex, $no, $familyName, $firstName, $familyNameKana, $firstNameKana, $gender, $birthday, $email, $mobile,
+													$zipcode, $stateId, $address1, $address2, $phone, $fax, $countryId, $userId, $now));
+
+		// 新規のシリアル番号取得
+		$queryStr = 'select max(li_serial) as ns from _login_user_info ';
+		$ret = $this->selectRecord($queryStr, array(), $row);
+		if ($ret) $newSerial = $row['ns'];
+		
+		// トランザクション確定
+		if ($startTran) $ret = $this->endTransaction();
+		return $ret;
+	}
+	/**
+	 * ログインユーザ情報をIDで削除
+	 *
+	 * @param int	$id						ユーザID
+	 * @return bool							取得 = true, 取得なし= false
+	 */
+	function delLoginUserInfo($id)
+	{
+		global $gEnvManager;
+		
+		$startTran = false;			// この関数でトランザクションを開始したかどうか
+		$now = date("Y/m/d H:i:s");	// 現在日時
+		$userId = $gEnvManager->getCurrentUserId();	// 現在のユーザ
+		
+		// トランザクション開始
+		if (!$this->isInTransaction()){
+			$this->startTransaction();
+			$startTran = true;
+		}
+		
+		// 指定のIDのレコードが削除状態でないかチェック
+		$queryStr  = 'select * from _login_user_info ';
+		$queryStr .=   'WHERE li_id = ? ';
+		$queryStr .=    'and li_deleted = false';
+		$ret = $this->selectRecord($queryStr, array($id), $row);
+		if (!$ret){		// 登録レコードがないとき
+			if ($startTran) $this->endTransaction();
+			return false;
+		}
+		
+		// 古いレコードを削除
+		$queryStr  = 'UPDATE _login_user_info ';
+		$queryStr .=   'SET li_deleted = true, ';	// 削除
+		$queryStr .=     'li_update_user_id = ?, ';
+		$queryStr .=     'li_update_dt = ? ';
+		$queryStr .=   'WHERE li_serial = ?';
+		$this->execStatement($queryStr, array($userId, $now, $row['li_serial']));
+		
+		// トランザクション確定
+		if ($startTran) $ret = $this->endTransaction();
+		return $ret;
+	}
 }
 ?>
