@@ -41,8 +41,8 @@ define('M3_SYSTEM_DEBUG_OUT', true);// デバッグ文出力を行うかどう
 // ########## システム関係 ##########
 // システム基本情報
 define('M3_SYSTEM_NAME',			'Magic3');		// システム名称
-define('M3_SYSTEM_VERSION',			'1.3.4');		// システムのバージョン
-define('M3_SYSTEM_RELEASE_DATE',	'2008/4/7');	// システムのリリース日付
+define('M3_SYSTEM_VERSION',			'1.3.5');		// システムのバージョン
+define('M3_SYSTEM_RELEASE_DATE',	'2008/4/17');	// システムのリリース日付
 define('M3_SYSTEM_ID',				'M3');			// コンポーネント識別用ID
 define('M3_SYSTEM_DESCRIPTION',		'Magic3 is open source cms & web communication platform.');		// システムの説明
 
@@ -129,8 +129,10 @@ define('M3_REQUEST_PARAM_OPERATION_TODO',      		'todo');			// 指定ウィジ
 define('M3_REQUEST_PARAM_FROM',						'from');			// メッセージの送信元ウィジェットID
 define('M3_REQUEST_PARAM_VIEW_STYLE',				'style');			// 表示スタイル
 define('M3_REQUEST_PARAM_FORWARD',					'forward');			// 画面遷移用パラメータ
-define('M3_REQUEST_PARAM_ADMIN_KEY',				'adminkey');			// 管理者一時キー
+define('M3_REQUEST_PARAM_ADMIN_KEY',				'adminkey');		// 管理者一時キー
 define('M3_REQUEST_PARAM_OPEN_BY',					'openby');			// ウィンドウの開き方
+define('M3_REQUEST_PARAM_PAGE_DEF_SERIAL',			'_defserial');		// ページ定義のレコードシリアル番号(設定画面起動時)
+define('M3_REQUEST_PARAM_PAGE_DEF_CONFIG_ID',		'_defconfig');		// ページ定義のウィジェット定義ID(設定画面起動時)
 
 // 値
 // 実行オペレーション
