@@ -268,5 +268,14 @@ class AccessManager
 		$ret = $this->db->isValidAdminKey($adminKey, $request->trimServerValueOf('REMOTE_ADDR'));
 		return $ret;
 	}
+	/**
+	 * URL用のパラメータとして使用するセッションIDを取得
+	 *
+	 * @return string			セッションIDパラメータ文字列
+	 */	
+	function getSessionIdUrlParam()
+	{
+		return session_name() . '=' . session_id();
+	}
 }
 ?>
