@@ -750,7 +750,8 @@ class PageManager
 		// キャラクターセット
 		echo '<meta http-equiv="content-type" content="text/html; charset=' . M3_HTML_CHARSET .'" />' . M3_NL;
 		// 基準ディレクトリの指定
-		if ($cmd == M3_REQUEST_CMD_SHOW_POSITION_WITH_WIDGET){		// ウィジェット付きポジション表示
+		if ($cmd == M3_REQUEST_CMD_SHOW_POSITION ||				// 表示位置を表示するとき
+			$cmd == M3_REQUEST_CMD_SHOW_POSITION_WITH_WIDGET){	// 表示位置を表示するとき(ウィジェット付き)
 			echo '<base href="' . $gEnvManager->getRootUrl() . '/" />' . M3_NL;
 		}
 		
@@ -1119,11 +1120,11 @@ class PageManager
 						$hasAdmin = '1';
 					}
 					if (empty($this->pageDefRows[$i]['pd_sub_id'])){		// 共通ウィジェットのときは色を変える
-						$menuItem1 = 'ページ共通を解除';
+						$menuItem1 = 'ページ共通属性を解除';
 						//echo '<div id="' . $widgetTag . '" class="' . self::WIDTET_CLASS_NAME . '" ondblclick="m3DoubleClickWidget(event, this, \'' . $widgetId . '\');" style="background-color:#ffe4c4;margin:2px;padding:10px;border:2px solid green;color:#800000;" context="widget" common="1" widgetid="' . $widgetId . '" config="' . $hasAdmin . '" configid="' . $configId . '" serial="' . $serial . '" menu1="' . $menuItem1 . '" >';
 						echo '<div id="' . $widgetTag . '" class="' . self::WIDTET_CLASS_TYPE_1 . '" ondblclick="m3DoubleClickWidget(event, this, \'' . $widgetId . '\');" context="widget" common="1" widgetid="' . $widgetId . '" config="' . $hasAdmin . '" configid="' . $configId . '" serial="' . $serial . '" menu1="' . $menuItem1 . '" >';
 					} else {
-						$menuItem1 = 'ページ共通に設定';
+						$menuItem1 = 'ページ共通属性を設定';
 						//echo '<div id="' . $widgetTag . '" class="' . self::WIDTET_CLASS_NAME . '" ondblclick="m3DoubleClickWidget(event, this, \'' . $widgetId . '\');" style="background-color:#ffe4c4;margin:2px;padding:10px;border:2px solid #b22222;color:#800000;" context="widget" common="0" widgetid="' . $widgetId . '" config="' . $hasAdmin . '" configid="' . $configId . '" serial="' . $serial . '" menu1="' . $menuItem1 . '" >';
 						echo '<div id="' . $widgetTag . '" class="' . self::WIDTET_CLASS_TYPE_0 . '" ondblclick="m3DoubleClickWidget(event, this, \'' . $widgetId . '\');" context="widget" common="0" widgetid="' . $widgetId . '" config="' . $hasAdmin . '" configid="' . $configId . '" serial="' . $serial . '" menu1="' . $menuItem1 . '" >';
 					}
