@@ -10,7 +10,7 @@
  *
  * @package    Magic3 Framework
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
- * @copyright  Copyright 2006-2007 Magic3 Project.
+ * @copyright  Copyright 2006-2008 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
  * @version    SVN: $Id$
  * @link       http://www.magic3.org
@@ -29,4 +29,12 @@ $mosConfig_favicon = 'favicon.ico';
 $mosConfig_sef = '0';
 $cur_template = $gEnvManager->getCurrentTemplateId();
 
+// グローバルオブジェクト
+class mosMainFrame {
+	function getTemplate(){
+		global $cur_template;
+		return $cur_template;
+	}
+}
+$mainframe = new mosMainFrame();
 ?>
