@@ -194,7 +194,7 @@ CREATE TABLE _login_user (
     lu_password          CHAR(32)       DEFAULT ''                    NOT NULL,      -- ログインパスワード(MD5)
     lu_name              VARCHAR(40)    DEFAULT ''                    NOT NULL,      -- ユーザ名
     lu_user_type         SMALLINT       DEFAULT 0                     NOT NULL,      -- ユーザタイプ(0=仮ユーザ、10=一般ユーザ、20=サイト運営者、100=システム管理者)
-    lu_subject           TEXT           DEFAULT ''                    NOT NULL,      -- ログイン可能な機能(カンマ区切り、1=システム管理機能、2=EC、3=ブログ、4=BBS)
+    lu_assign            TEXT           DEFAULT ''                    NOT NULL,      -- ログイン可能な機能(2バイト文字カンマ区切り、sy=システム管理機能、ec=EC、bg=ブログ、bs=BBS、rv=予約)
     lu_user_status       SMALLINT       DEFAULT 0                     NOT NULL,      -- ユーザの状態
     lu_enable_login      BOOLEAN        DEFAULT true                  NOT NULL,      -- ログイン許可
     lu_active_start_dt   TIMESTAMP      DEFAULT '0000-00-00 00:00:00' NOT NULL,      -- ログイン可能期間(開始)
@@ -210,8 +210,41 @@ CREATE TABLE _login_user (
     PRIMARY KEY          (lu_serial),
     UNIQUE               (lu_id,        lu_history_index)
 ) TYPE=innodb;
-INSERT INTO `_login_user` (`lu_id`, `lu_account`, `lu_password`, `lu_name`,  `lu_user_type`, `lu_subject`, `lu_create_dt`) VALUES
-(1,     'admin',    md5('admin'),     '管理者', 100,          '1,',       now());
+INSERT INTO `_login_user` (`lu_id`, `lu_account`, `lu_password`, `lu_name`,  `lu_user_type`, `lu_assign`, `lu_create_dt`) VALUES
+(1,     'admin',    md5('admin'),     '管理者', 100,          'sy,',       now());
+
+-- ログインユーザ情報マスター(共通的に任意で使用するユーザ情報テーブル)
+DROP TABLE IF EXISTS _login_user_info;
+CREATE TABLE _login_user_info (
+    li_serial            INT            AUTO_INCREMENT,                              -- レコードシリアル番号
+    li_id                INT            DEFAULT 0                     NOT NULL,      -- ログインユーザID
+    li_history_index     INT            DEFAULT 0                     NOT NULL,      -- 履歴管理用インデックスNo(0～)
+
+    li_no                VARCHAR(40)    DEFAULT ''                    NOT NULL,      -- 任意利用No
+    li_family_name       VARCHAR(20)    DEFAULT ''                    NOT NULL,      -- ユーザ名(姓)漢字
+    li_first_name        VARCHAR(20)    DEFAULT ''                    NOT NULL,      -- ユーザ名(名)漢字
+    li_family_name_kana  VARCHAR(20)    DEFAULT ''                    NOT NULL,      -- ユーザ名(姓)カナ
+    li_first_name_kana   VARCHAR(20)    DEFAULT ''                    NOT NULL,      -- ユーザ名(名)カナ
+    li_gender            SMALLINT       DEFAULT 0                     NOT NULL,      -- 性別(0=未設定、1=男、2=女)
+    li_birthday          DATE           DEFAULT '0000-00-00'          NOT NULL,      -- 誕生日(西暦)
+    li_email             VARCHAR(40)    DEFAULT ''                    NOT NULL,      -- Eメールアドレス
+    li_mobile            VARCHAR(30)    DEFAULT ''                    NOT NULL,      -- 携帯電話
+    li_zipcode           VARCHAR(10)    DEFAULT ''                    NOT NULL,      -- 郵便番号(7桁)
+    li_state_id          INT            DEFAULT 0                     NOT NULL,      -- 都道府県、州(geo_zoneテーブル)
+    li_address1          VARCHAR(100)   DEFAULT ''                    NOT NULL,      -- 市区町村
+    li_address2          VARCHAR(60)    DEFAULT ''                    NOT NULL,      -- ビル・マンション名等
+    li_phone             VARCHAR(30)    DEFAULT ''                    NOT NULL,      -- 電話番号
+    li_fax               VARCHAR(30)    DEFAULT ''                    NOT NULL,      -- FAX
+    li_country_id        VARCHAR(3)     DEFAULT ''                    NOT NULL,      -- 国ID
+
+    li_create_user_id    INT            DEFAULT 0                     NOT NULL,      -- レコード作成者
+    li_create_dt         TIMESTAMP      DEFAULT '0000-00-00 00:00:00' NOT NULL,      -- レコード作成日時
+    li_update_user_id    INT            DEFAULT 0                     NOT NULL,      -- レコード更新者
+    li_update_dt         TIMESTAMP      DEFAULT '0000-00-00 00:00:00' NOT NULL,      -- レコード更新日時
+    li_deleted           BOOLEAN        DEFAULT false                 NOT NULL,      -- レコード削除状態
+    PRIMARY KEY          (li_serial),
+    UNIQUE               (li_id,        li_history_index)
+) TYPE=innodb;
 
 -- ユーザログイントラン
 DROP TABLE IF EXISTS _login_log;
@@ -508,22 +541,26 @@ CREATE TABLE _page_id (
     pg_description       VARCHAR(60)    DEFAULT ''                    NOT NULL,      -- 説明
     pg_priority          INT            DEFAULT 0                     NOT NULL,      -- 優先度
     pg_is_public         BOOLEAN        DEFAULT false                 NOT NULL,      -- URLの公開
+    pg_mobile            BOOLEAN        DEFAULT false                 NOT NULL,      -- 携帯対応かどうか
     pg_editable          BOOLEAN        DEFAULT true                  NOT NULL,      -- データ編集可能かどうか
     PRIMARY KEY  (pg_id, pg_type)
 ) TYPE=innodb;
-INSERT INTO `_page_id` (`pg_id`,         `pg_type`, `pg_default_sub_id`, `pg_path`,       `pg_name`,          `pg_description`,                     `pg_priority`, `pg_is_public`, `pg_editable`) VALUES
-('index',       0,       'content',      'index',       'index',          'PC用アクセスポイント',                0,true,true),
-('m_index',     0,       'content',      'm/index',     'm_index',        '携帯用アクセスポイント',              1,true,true),
-('admin_index', 0,       'content',         'admin/index', 'admin_index',    '管理用アクセスポイント',           2,true,false),
-('content',     1,       '',                '',            'コンテンツ',     'コンテンツ画面用',                 0,true,false),
-('shop',        1,       '',                '',            'ECショップ',     'ECショップ画面用',                 1,true,true),
-('bbs',         1,       '',                '',            '掲示板',         '掲示板画面用',                     2,true,true),
-('blog',        1,       '',                '',            'ブログ',         'ブログ画面用',                     3,true,true),
-('photo',       1,       '',                '',            'フォトアルバム', 'フォトアルバム画面用',             4,true,true),
-('contact',     1,       '',                '',            'お問い合わせ',   'お問い合わせ画面用',               5,true,true),
-('safe',        1,       '',                '',            'セキュリティ保護',   'セキュリティ保護画面用',       6,true,true),
-('custom_admin',1,       '',                '',            '管理用任意',     '管理用任意編集画面用',             9,false,true),
-('test',        1,       '',                '',            'テスト用',       'テスト用非公開画面',               10,false,true);
+INSERT INTO _page_id (pg_id,         pg_type, pg_default_sub_id, pg_path,       pg_name,          pg_description,                     pg_priority, pg_is_public, pg_mobile, pg_editable) VALUES
+('index',       0,       'content',      'index',       'index',          'PC用アクセスポイント',                0,true,false,true),
+('m_index',     0,       'content',      'm/index',     'm_index',        '携帯用アクセスポイント',              1,true,true,true),
+('admin_index', 0,       'content',         'admin/index', 'admin_index',    '管理用アクセスポイント',           2,true,false,false),
+('face',        1,       '',                '',            'トップ専用',     'トップ専用画面用',                 0,true,false,true),
+('content',     1,       '',                '',            'コンテンツ',     'コンテンツ画面用',                 1,true,false,false),
+('shop',        1,       '',                '',            'ECショップ',     'ECショップ画面用',                 2,true,false,true),
+('shop_safe',        1,       '',                '',            'ECショップ(セキュリティ保護)',     'ECショップ(セキュリティ保護)画面用',                 3,true,false,true),
+('bbs',         1,       '',                '',            '掲示板',         '掲示板画面用',                     4,true,false,true),
+('blog',        1,       '',                '',            'ブログ',         'ブログ画面用',                     5,true,false,true),
+('photo',       1,       '',                '',            'フォトアルバム', 'フォトアルバム画面用',             6,true,false,true),
+('contact',     1,       '',                '',            'お問い合わせ',   'お問い合わせ画面用',               7,true,false,true),
+('reserve',     1,       '',                '',            '予約',           '予約画面用',                       8,true,false,true),
+('safe',        1,       '',                '',            'セキュリティ保護',   'セキュリティ保護画面用',       9,true,false,true),
+('custom_admin',1,       '',                '',            '自由編集',       '管理用自由編集画面用',             100,false,false,true),
+('test',        1,       '',                '',            'テスト用',       'テスト用非公開画面',               101,false,false,true);
 
 -- ページオプションマスター
 DROP TABLE IF EXISTS _page_option;
@@ -575,7 +612,8 @@ CREATE TABLE _page_def (
 ) TYPE=innodb;
 INSERT INTO `_page_def` (`pd_id`,         `pd_sub_id`, `pd_position_id`, `pd_index`, `pd_widget_id`,       `pd_config_id`, `pd_visible`, `pd_editable`, `pd_update_dt`) VALUES
 ('admin_index', '',        'top',          1,        'admin_menu2',       0,                   true,       false,       now()),
-('admin_index', 'content',        'main',         1,        'admin_main',       0,                   true,       false,       now());
+('admin_index', 'content',        'main',         1,        'admin_main',       0,                   true,       false,       now()),
+('admin_index', 'custom_admin',   'left',         1,        'release_info',       0,                   true,       false,       now());
 
 -- ページ定義セットマスター
 DROP TABLE IF EXISTS _page_def_set;
