@@ -100,6 +100,16 @@ class _installCheckenvWidgetContainer extends BaseWidgetContainer
 		}
 		$this->tmpl->addVar("_widget","current_php_version", $data);
 		
+		// セーフモード
+		$data = '<b><font color="green">off</font></b>';
+		$this->tmpl->addVar("_widget","config_safe_mode", $data);
+		if (ini_get('safe_mode')){
+			$data = '<b><font color="red">on</font></b>';
+		} else {
+			$data = '<b><font color="green">off</font></b>';
+		}
+		$this->tmpl->addVar("_widget","current_safe_mode", $data);
+	
 		// ######## PHP拡張オプションのインストール状況 ########
 		// PDO
 		$data = '<b><font color="green">on</font></b>';
@@ -120,6 +130,16 @@ class _installCheckenvWidgetContainer extends BaseWidgetContainer
 			$data = '<b><font color="red">off</font></b>';
 		}
 		$this->tmpl->addVar("_widget","current_mbstring", $data);
+		// mbstring.encoding_translation
+		$data = '<b><font color="green">off</font></b>';
+		$this->tmpl->addVar("_widget","config_mbstring_tran", $data);
+		if (ini_get('mbstring.encoding_translation')){
+			$data = '<b><font color="red">on</font></b>';
+		} else {
+			$data = '<b><font color="green">off</font></b>';
+		}
+		$this->tmpl->addVar("_widget","current_mbstring_tran", $data);
+
 		// gd
 		$data = '<b><font color="green">offでも動作可</font></b>';
 		$this->tmpl->addVar("_widget","config_gd", $data);
