@@ -8,7 +8,7 @@
  *
  * @package    Magic3 Framework
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
- * @copyright  Copyright 2006-2007 Magic3 Project.
+ * @copyright  Copyright 2006-2008 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
  * @version    SVN: $Id$
  * @link       http://www.magic3.org
@@ -259,9 +259,10 @@ class admin_mainTemplistWidgetContainer extends BaseWidgetContainer
 			// セッションのテンプレートIDを更新
 			$request->setSessionValue(M3_SESSION_CURRENT_TEMPLATE, $templateId);
 		}
-		// インストールディレクトリを設定
-		$this->tmpl->addVar("_widget", "install_dir", $gEnvManager->getTemplatesPath());
-		
+		// パラメータを設定
+		$this->tmpl->addVar("_widget", "install_dir", $gEnvManager->getTemplatesPath());// インストールディレクトリ
+		$this->tmpl->addVar("_widget", "admin_url", $gEnvManager->getDefaultAdminUrl());// 管理用URL
+				
 		// テンプレートリストを取得
 		$this->db->getAllTemplateList(array($this, 'tempListLoop'));
 	}
