@@ -368,14 +368,16 @@ class admin_mainDb extends BaseDb
 	 *
 	 * @param function $callback	コールバック関数
 	 * @param int $type				リストの種別
+	 * @param bool $mobile			携帯対応かどうか
 	 * @return						なし
 	 */
-	function getPageIdList($callback, $type)
+	function getPageIdList($callback, $type, $mobile = false)
 	{
-		$queryStr = 'select * from _page_id ';
-		$queryStr .=  'where pg_type = ? ';
-		$queryStr .=  'order by pg_priority';
-		$this->selectLoop($queryStr, array($type), $callback);
+		$queryStr = 'SELECT * FROM _page_id ';
+		$queryStr .=  'WHERE pg_type = ? ';
+		$queryStr .=  'AND pg_mobile = ? ';
+		$queryStr .=  'ORDER BY pg_priority';
+		$this->selectLoop($queryStr, array($type, $mobile), $callback);
 	}
 	/**
 	 * ページIDのリストを取得
@@ -1026,7 +1028,7 @@ class admin_mainDb extends BaseDb
 		$queryStr .=   'lu_account, ';
 		$queryStr .=   'lu_password, ';
 		$queryStr .=   'lu_user_type, ';
-		$queryStr .=   'lu_subject, ';
+		$queryStr .=   'lu_assign, ';
 		$queryStr .=   'lu_widget_id, ';
 		$queryStr .=   'lu_enable_login, ';
 		$queryStr .=   'lu_create_user_id, ';
@@ -1043,7 +1045,7 @@ class admin_mainDb extends BaseDb
 		$queryStr .=   '?, ';
 		$queryStr .=   '?, ';
 		$queryStr .=   '?) ';
-		$this->execStatement($queryStr, array($row['lu_id'], $historyIndex, $name, $account, $pwd, $userType, $row['lu_subject'], $row['lu_widget_id'], $canLogin, $userId, $now));
+		$this->execStatement($queryStr, array($row['lu_id'], $historyIndex, $name, $account, $pwd, $userType, $row['lu_assign'], $row['lu_widget_id'], $canLogin, $userId, $now));
 
 		// 新規のシリアル番号取得
 		$queryStr = 'select max(lu_serial) as ns from _login_user ';
