@@ -25,6 +25,7 @@ class admin_ec_mainDelivmethodWidgetContainer extends admin_ec_mainBaseWidgetCon
 	private $serialNo;		// 選択中の項目のシリアル番号
 	private $serialArray = array();		// 表示されている項目シリアル番号
 	const IWIDGET_TYPE = 'DELIVERY';		// 配送方法用インナーウィジェット
+	const TARGET_WIDGET = 'ec_main';		// プレビュー画面表示用
 	
 	/**
 	 * コンストラクタ
@@ -86,6 +87,7 @@ class admin_ec_mainDelivmethodWidgetContainer extends admin_ec_mainBaseWidgetCon
 	function createList($request)
 	{
 		global $gEnvManager;
+		global $gPageManager;
 		
 		$this->langId	= $gEnvManager->getCurrentLanguage();		// 表示言語を取得
 		$act = $request->trimValueOf('act');
@@ -115,6 +117,10 @@ class admin_ec_mainDelivmethodWidgetContainer extends admin_ec_mainBaseWidgetCon
 		$this->db->getAllDelivMethodDef($this->langId, 0/*デフォルトのセットID*/, array($this, 'delivDefLoop'));
 		
 		$this->tmpl->addVar("_widget", "serial_list", implode($this->serialArray, ','));// 表示項目のシリアル番号を設定
+		
+		// プレビュー表示ボタンのリンクを作成
+		$url = $gPageManager->createWidgetCmdUrl($gEnvManager->getDefaultPageId(), self::TARGET_WIDGET, ''/*送信元ウィジェット指定なし*/, 'task=delivery');
+		$this->tmpl->addVar("_widget", "url", $url);
 	}
 	/**
 	 * 詳細画面作成
