@@ -85,7 +85,7 @@ class ec_mainAgreememberWidgetContainer extends BaseWidgetContainer
 		}
 		
 		// 登録したキーワードを変換
-		$gTextConvManager->convByKeyValue($contentText, $contentText, true/*改行コーをbrタグに変換*/);
+		$gTextConvManager->convByKeyValue($content, $content, true/*改行コーをbrタグに変換*/);
 		
 		$this->tmpl->addVar("_widget", "content", $content);		// 会員規約
 		$this->tmpl->addVar("_widget", "cancel_url", $gEnvManager->createCurrentPageUrl());		// キャンセル用URL
