@@ -8,7 +8,7 @@
  *
  * @package    Magic3 Framework
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
- * @copyright  Copyright 2006-2007 Magic3 Project.
+ * @copyright  Copyright 2006-2008 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
  * @version    SVN: $Id$
  * @link       http://www.magic3.org
@@ -145,6 +145,7 @@ class ec_mainConfirmWidgetContainer extends BaseWidgetContainer
 				// データ再取得
 				$ret = $this->db->getOrder($this->orderId, $row);
 				if ($ret){
+					$orderNo = $row['or_order_no'];		// 注文番号
 					$name = $row['or_deliv_name'];
 					$nameKana = $row['or_deliv_name_kana'];
 					$zipcode = $row['or_deliv_zipcode'];
@@ -208,11 +209,6 @@ class ec_mainConfirmWidgetContainer extends BaseWidgetContainer
 					
 					// 受注データに送料、手数料を追加
 					$delim = $gEnvManager->getDefaultCsvDelimCode();		// CSV区切りコードを取得
-					/*if ($gEnvManager->getDefaultCsvDelim() == 0){		// タブ区切りのCSVフォーマットのとき
-						$delim = "\t";
-					} else {
-						$delim = ",";
-					}*/
 					$this->mailData .= 'delivery' . $delim . $deliveryFeeValue . "\n";
 					$this->mailData .= 'charge' . $delim . $chargeValue . "\n";
 					
@@ -225,7 +221,7 @@ class ec_mainConfirmWidgetContainer extends BaseWidgetContainer
 				$this->db->delOrderSheet($this->userId, $this->langId);
 				
 				// ######## イントラ側に受注情報メールを送信 ########
-				$this->sendMailToBackoffice(0/*新規登録*/, $memberNo, $email, $memberName/*会員名*/,
+				$this->sendMailToBackoffice(0/*新規登録*/, $orderNo, $memberNo, $email, $memberName/*会員名*/,
 						$name, $nameKana, $zipcode, $address/*配送先住所1*/, $address2/*配送先住所2*/, $phone, $demand_dt, $demand_time, $delivMethodName, $payMethodName, '', $this->mailData/*受注明細*/);
 			} else {
 				$this->setAppErrorMsg('登録処理に失敗しました。');
@@ -351,7 +347,7 @@ class ec_mainConfirmWidgetContainer extends BaseWidgetContainer
 		$id = $fetchedRow['si_product_id'];	// 商品ID
 		
 		// 商品を取得
-		$ret = $this->cartDb->getProductByProductId($id, $this->langId, $row, $row2, $row3, $row4);
+		$ret = $this->cartDb->getProductByProductId($id, $this->langId, $row, $row2, $row3, $row4, $row5);
 		if ($ret){
 			$name = $this->convertToDispString($row['pt_name']);		// 名前
 			$code = $this->convertToDispString($row['pt_code']);		// 商品コード
@@ -425,11 +421,6 @@ class ec_mainConfirmWidgetContainer extends BaseWidgetContainer
 		// メール送信用の受注データを作成
 		if ($this->createMailData){	// メール送信用の受注データを作成するかどうか
 			$delim = $gEnvManager->getDefaultCsvDelimCode();		// CSV区切りコードを取得
-			/*if ($gEnvManager->getDefaultCsvDelim() == 0){		// タブ区切りのCSVフォーマットのとき
-				$delim = "\t";
-			} else {
-				$delim = ",";
-			}*/
 			$mailData = $code . $delim . $name . $delim . $this->ecObj->getCurrencyPrice($unitPrice) . $delim . $quantity . "\n";
 			$this->mailData .= $mailData;			// メール送信用の受注データ
 		}
@@ -453,7 +444,7 @@ class ec_mainConfirmWidgetContainer extends BaseWidgetContainer
 		$subtotal = $fetchedRow['si_subtotal'];
 		
 		// 商品を取得
-		$ret = $this->cartDb->getProductByProductId($id, $this->langId, $row, $row2, $row3, $row4);
+		$ret = $this->cartDb->getProductByProductId($id, $this->langId, $row, $row2, $row3, $row4, $row5);
 		if ($ret){
 			$name = $this->convertToDispString($row['pt_name']);		// 名前
 			$code = $this->convertToDispString($row['pt_code']);		// 商品コード
@@ -516,9 +507,10 @@ class ec_mainConfirmWidgetContainer extends BaseWidgetContainer
 		return $no;
 	}
 	/**
-	 * イントラネット側に会員登録、更新情報をメール送信する
+	 * イントラネット側に受注登録、更新情報をメール送信する
 	 *
-	 * @param int $mailType			メールタイプ(0=会員情報登録、1=更新、2=削除)
+	 * @param int $mailType			メールタイプ(0=受注情報登録、1=更新、2=削除)
+	 * @param string $orderNo		注文No
 	 * @param string $memberNo		会員No
 	 * @param string $email			eメール(ログインアカウント)
 	 * @param string $memberName			会員名
@@ -536,7 +528,7 @@ class ec_mainConfirmWidgetContainer extends BaseWidgetContainer
 	 * @param string $orderDetail	受注明細データ
 	 * @return bool					true=成功、false=失敗
 	 */
-	function sendMailToBackoffice($mailType, $memberNo, $email, $memberName, $delivName, $nameKana, $zipcode, $address1, $address2, $phone, 
+	function sendMailToBackoffice($mailType, $orderNo, $memberNo, $email, $memberName, $delivName, $nameKana, $zipcode, $address1, $address2, $phone, 
 									$demandDt, $demandTime, $delivMethod, $payMethod, $note, $orderDetail)
 	{	
 		global $gEnvManager;
@@ -560,6 +552,7 @@ class ec_mainConfirmWidgetContainer extends BaseWidgetContainer
 			$subject = $memberNo . ':' . $memberName . ':' . $now . ':' . $operation;
 			$mailParam = array();
 			//$mailParam['PASSWORD'] = $password;
+			$mailParam['ORDER_NO'] = $orderNo;		// 受注No
 			$mailParam['DATE'] = date("Y/m/d");		// 受付日付
 			$mailParam['MEMBER_NO'] = $memberNo;
 			$mailParam['EMAIL'] = $email;
