@@ -104,7 +104,7 @@ class admin_imageWidgetContainer extends BaseWidgetContainer
 		// 実行モードの取得
 		$value = $request->trimValueOf('configmode');
 		if ($value == ''){
-			if ($request->trimValueOf('configid') != '' && $request->trimValueOf('serial') != ''){		// 定義ID可変モードのとき
+			if ($request->trimValueOf('_defconfig') != '' && $request->trimValueOf('_defserial') != ''){		// 定義ID可変モードのとき
 				$this->configMode = 1;		// 可変
 			} else {
 				$this->configMode = 0;		// デフォルト固定
