@@ -25,7 +25,7 @@ class admin_m_mainmenuWidgetContainer extends BaseWidgetContainer
 	private $currentPageSubId;	// 現在のページサブID
 	private $currentContentId;	// 現在のコンテンツID
 	const MAIN_MENU_ID = 'mobile_menu';			// メニューID
-	const CONTENT_WIDGET_ID = 'default_content';			// コンテンツ編集ウィジェット
+	const CONTENT_WIDGET_ID = 'm/content';			// コンテンツ編集ウィジェット
 	const CONTENT_TYPE = 'mobile';					// コンテンツタイプ
 	
 	/**
@@ -340,10 +340,10 @@ class admin_m_mainmenuWidgetContainer extends BaseWidgetContainer
 			}
 		}
 		// リンク先を実URLに変換
-		$linkUrlStr = str_replace(M3_TAG_START . M3_TAG_MACRO_ROOT_URL . M3_TAG_END, $gEnvManager->getRootUrl() . '<br>', $linkUrl);		// 表示テキストは改行を入れる
+		$linkUrlStr = str_replace(M3_TAG_START . M3_TAG_MACRO_ROOT_URL . M3_TAG_END, $gEnvManager->getRootUrl(), $linkUrl);
 		$linkUrl = str_replace(M3_TAG_START . M3_TAG_MACRO_ROOT_URL . M3_TAG_END, $gEnvManager->getRootUrl(), $linkUrl);		// マクロ展開
 		//$linkUrlStr = '<div style="overflow:auto;width:300px"><a href="#" title="'. $linkUrl . '" onClick="showUrl(\'' . $linkUrl . '\');">' . $linkUrlStr . '</a></div>';
-		$linkUrlStr = '<div style="overflow:auto;width:300px"><a href="#" onClick="showUrl(\'' . $linkUrl . '\');">' . $linkUrlStr . '</a></div>';
+		$linkUrlStr = '<div style="overflow:auto;width:500px"><a href="#" onClick="showUrl(\'' . $linkUrl . '\');">' . $linkUrlStr . '</a></div>';
 		
 		// コンテンツの編集ボタンの有効状態
 		$enableContentLink = '';
